Changes in directory llvm/lib/Target/PowerPC:

PPCISelLowering.cpp updated: 1.65 -> 1.66
---
Log message:

bswap implementation


---
Diffs of the changes:  (+2 -1)

 PPCISelLowering.cpp |    3 ++-
 1 files changed, 2 insertions(+), 1 deletion(-)


Index: llvm/lib/Target/PowerPC/PPCISelLowering.cpp
diff -u llvm/lib/Target/PowerPC/PPCISelLowering.cpp:1.65 
llvm/lib/Target/PowerPC/PPCISelLowering.cpp:1.66
--- llvm/lib/Target/PowerPC/PPCISelLowering.cpp:1.65    Fri Jan 13 11:52:03 2006
+++ llvm/lib/Target/PowerPC/PPCISelLowering.cpp Fri Jan 13 21:14:10 2006
@@ -64,7 +64,8 @@
     setOperationAction(ISD::FSQRT, MVT::f32, Expand);
   }
   
-  // PowerPC does not have CTPOP or CTTZ
+  // PowerPC does not have BSWAP, CTPOP or CTTZ
+  setOperationAction(ISD::BSWAP, MVT::i32  , Expand);
   setOperationAction(ISD::CTPOP, MVT::i32  , Expand);
   setOperationAction(ISD::CTTZ , MVT::i32  , Expand);
   



_______________________________________________
llvm-commits mailing list
llvm-commits@cs.uiuc.edu
http://lists.cs.uiuc.edu/mailman/listinfo/llvm-commits

Reply via email to